#[repr(C)]pub struct FundingSettlement {
pub trader_id: TraderId,
pub instrument_id: InstrumentId,
pub account_id: AccountId,
pub rate: Decimal,
pub settlement_price: Price,
pub currency: Currency,
pub event_id: UUID4,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a funding settlement for a perpetual swap instrument.
Fields
trader_id: TraderIdThe trader ID associated with the event.
instrument_id: InstrumentIdThe instrument ID for the settlement.
account_id: AccountIdThe account ID receiving the settlement.
rate: DecimalThe funding rate applied for the settlement.
settlement_price: PriceThe mark or settlement price used to value open positions.
currency: CurrencyThe currency for resulting funding payments.
event_id: UUID4The unique identifier for the event.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the event was initialized.
Implementations
Sourceimpl FundingSettlement
impl FundingSettlement
Sourcepub const fn new(
trader_id: TraderId,
instrument_id: InstrumentId,
account_id: AccountId,
rate: Decimal,
settlement_price: Price,
currency: Currency,
event_id: UUID4,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub const fn new( trader_id: TraderId, instrument_id: InstrumentId, account_id: AccountId, rate: Decimal, settlement_price: Price, currency: Currency, event_id: UUID4, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new FundingSettlement instance.